summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlightedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlightedit.h')
-rw-r--r--kpovmodeler/pmlightedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmlightedit.h b/kpovmodeler/pmlightedit.h
index 62451ed3..75b56530 100644
--- a/kpovmodeler/pmlightedit.h
+++ b/kpovmodeler/pmlightedit.h
@@ -41,12 +41,13 @@ class TQCheckBox;
class PMLightEdit : public PMNamedObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMNamedObjectEdit Base;
public:
/**
* Creates a PMLightEdit with parent and name
*/
- PMLightEdit( TQWidget* parent, const char* name = 0 );
+ PMLightEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -41,12 +41,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMLightEdit with parent and name
+ * Creates a PMLightEdit with tqparent and name
*/